// Persistence of Vision Ray Tracer Scene Description File
// File: tower.pov
// Vers: 0.2
// Desc: The Tower of Man
// Date: 2007-12-18
// Auth: Felix Plesoianu <felixp7@yahoo.com>

#include "colors.inc"
#include "textures.inc"

#declare Ambiental = <0.5, 0.5, 0.5>;

#declare White_Ceramics =
texture {
	pigment { color White }
	finish {
		diffuse 0.6
		specular 0.8
		ambient Ambiental
	}
}

#declare Dark_Glass =
texture {
	pigment { color rgb <0.25, 0.25, 0> }
	finish {
		ambient <0.8, 0.8, 0.8>
		diffuse 0
		specular 0.2
		reflection {
			<0.35, 0.35, 0.11>
		}
	}
}

#declare Facade =
texture {
	checker texture { Dark_Glass }, texture { White_Ceramics }
	scale <1000, 2, 1000>
}


//background { SkyBlue }
//background { rgb <0.5, 0.65, 0.8> }
sky_sphere {
	pigment {
		gradient y
		color_map {
			[0.5 color White]
			[0.75 color rgb <0.5, 0.65, 0.8>]
		}
		scale 2
		translate -1
	}
}

// Aerial perspective
/*fog {
	fog_type 1 distance 3000
	color rgb <0.5, 0.65, 0.8>
}*/

light_source { <1000, 1000, 0> color White parallel point_at <0, 0, 0> }

camera {
	location <400, 1.73, 400>
	look_at <0, 200, 0>
	angle 60
}


// The ground
disc {
	<0, 0, 0>, <0, 1, 0>, 20000
	texture { White_Ceramics }
	normal { cells scale x * 10 + z * 10 }
}

#declare Tall_Wing =
difference {
	cylinder {
		<0, 0, 0>, <0, 450, 0>, 150
		texture { Facade }
	}
	// Hollow it
	cylinder {
		<0, -1, 0>, <0, 451, 0>, 145
		scale <1, 1, 0.9>
		texture { Facade }
	}
	// Cut in half
	box {
		<-151, 0, 0>, <151, 450, 150>
	}
	// Give curved profile
	cylinder {
		<-151, 0, 0>, <151, 0, 0>, 150
		scale <1, 3, 1>
		translate <0, 450, 0>
	}
	bounded_by { box { <-151, 0, 0>, <151, 450, -150> } }
	scale <1, 1, 1.25>
}

#declare Low_Wing =
difference {
	cylinder {
		<0, 0, 0>, <0, 300, 0>, 150
		texture {
			Dark_Glass
		}
	}
	// Hollow it
	cylinder {
		<0, -1, 0>, <0, 301, 0>, 145
		scale <1, 1, 0.9>
	}
	// Cut in half
	box {
		<-151, 0, 0>, <151, 300, 150>
	}
	// Give curved profile
	cylinder {
		<-151, 0, 0>, <151, 0, 0>, 150
		scale <1, 2, 1>
		translate <0, 300, 0>
	}
	bounded_by { box { <-151, 0, 0>, <151, 300, -150> } }
	scale <1, 1, 1.25>
}

#declare Platform =
difference {
	cylinder {
		<0, 0, 0>, <0, 2, 0>, 75
	}
	cylinder {
		<0, -0.1, 0>, <0, 2.1, 0>, 55
	}
}

// The building
union {
	object {
		Tall_Wing
		translate <0, 0, 150>
	}
	object {
		Low_Wing
		rotate <0, 180, 0>
		translate <0, 0, -150>
	}
	union {
		object {
			Platform
			translate <0, 50, 0>
		}
		object {
			Platform
			translate <0, 100, 0>
		}
		object {
			Platform
			translate <0, 150, 0>
		}
		box { <-1, 0, 62.5>, <1, 200, 67.5> }
		box { <-16, 0, 62.5>, <-14, 200, 67.5> }
		box { <16, 0, 62.5>, <14, 200, 67.5> }
		scale <1, 1, 1.25>
	}
	texture { White_Ceramics }
}

// A good tree model would be overkill at that distance.
// Especially in 12 (well, 9) copies!
#declare Simple_Tree =
union {
	// The trunk
	cylinder {
		<0, 0, 0>, <0, 5.5, 0>, 0.25
		pigment { color rgb <0.25, 0, 0> }
		finish { ambient Ambiental }
	}
	// The foliage
	sphere {
		<0, 0, 0>, 0.75
		scale <1, 6, 1>
		translate <0, 5.5, 0>
		texture {
			hexagon
			texture {
				pigment {
					color rgb <0, 1, 0>
				}
			},
			texture {
				pigment {
					color rgbt <1, 1, 1, 1>
				}
			},
			texture {
				pigment {
					color rgbt <1, 1, 1, 1>
				}
			}
			scale <0.1, 0.1, 0.1>
			rotate <0, 0, -90>
		}
	}
}

#declare Tree_Angle = 15;
#while (Tree_Angle >= -105)
	object {
		Simple_Tree
		translate <200, 0, 0>
		rotate <0, Tree_Angle, 0>
	}
	#declare Tree_Angle = Tree_Angle - 15;
#end



#declare Plaza_Building_Module =
union {
	box {
		<-24, 0, -24>, <24, 2, 24>
		texture { Dark_Glass }
	}
	box {
		<-25, 2, -25>, <25, 4, 25>
		texture { White_Ceramics }
	}
}

#declare Plaza_Building_Floor =
union {
	object {
		Plaza_Building_Module
		translate <-10, 0, -10>
	}
	object {
		Plaza_Building_Module
		translate <10, 0, 10>
	}
}

#declare Plaza_Building =
union {
	#declare i = 0;
	#while (i < 20)
		#declare Hscale = 1 - i * 0.04;
		object {
			Plaza_Building_Floor
			scale <Hscale, 1, Hscale>
			translate y * i * 4
			rotate y * (90 + i * 3)
		}
		#declare i = i + 1;
	#end
}

object {
	Plaza_Building
	translate x * -400
}

object {
	Plaza_Building
	translate x * -400
	rotate y * 30
}

object {
	Plaza_Building
	translate z * -400
}

object {
	Plaza_Building
	translate z * -400
	rotate y * -30
}


#declare Avenue_Building_Module =
union {
	box {
		<-24, 0, -24>, <24, 2, 24>
		texture { Dark_Glass }
	}
	box {
		<-25, 2, -25>, <25, 4, 25>
		texture { White_Ceramics }
	}
}

#declare Avenue_Building_Floor =
union {
	object {
		Avenue_Building_Module
		scale z * 0.8
		translate <25, 0, 25>
	}
	object {
		Avenue_Building_Module
		scale z * 0.8
		translate <25, 0, -25>
	}
	object {
		Avenue_Building_Module
		scale x * 0.8
		translate <25, 0, 0>
	}
}

#declare Avenue_Building =
union {
	#declare i = 0;
	#while (i < 15)
		#declare Hscale = 1 - i * 0.04;
		object {
			Avenue_Building_Floor
			scale <Hscale, 1, Hscale>
			translate y * i * 4
		}
		#declare i = i + 1;		
	#end
	translate x * -25
}

object {
	Avenue_Building
	translate z * -600
}

object {
	Avenue_Building
	translate z * -750
}

object {
	Avenue_Building
	rotate y * -90
	translate x * -600
}

object {
	Avenue_Building
	rotate y * -90
	translate x * -750
}


// Faraway buildings
box {
	<-100, 40, -700>, <-200, 0, -800>
	texture {
		White_Ceramics
		normal { cells }
	}
}
box {
	<-700, 40, -100>, <-800, 0, -200>
	texture {
		White_Ceramics
		normal { cells }
	}
}


// El-cheapo hills
blob {
	threshold .5
	sphere {
		<-10000, 0, -2500>, 3000, 1
		pigment { color Brown transmit 0.65 }
	}
	sphere {
		<0, 0, 0>, 3000, 1
		scale <2, 0.5, 2>
		translate <-10000, 0, -3000>
		texture {
			pigment { Green transmit 0.5 }
			normal { bumps scale 10 }
		}
	}

	sphere {
		<-10000, 0, -7000>, 2000, 1
		texture {
			pigment { Green transmit 0.7 }
			normal { bumps scale 10 }
		}
	}
	sphere {
		<0, 0, 0>, 2000, 1
		scale <2, 0.5, 2>
		translate <-10000, 0, -7000>
		texture {
			pigment { Green transmit 0.65 }
			normal { bumps scale 10 }
		}
	}
	sphere {
		<0, 0, 0>, 2000, 1
		scale <2, 0.5, 2>
		translate <-10000, 0, -8000>
		texture {
			pigment { Green transmit 0.65 }
			normal { bumps scale 10 }
		}
	}

	sphere {
		<-10000, 0, -20000>, 3000, 1
		pigment { color Brown transmit 0.8 }
	}
	sphere {
		<0, 0, 0>, 3000, 1
		scale <2, 0.5, 2>
		translate <-10000, 0, -19000>
		texture {
			pigment { Green transmit 0.75 }
			normal { bumps scale 10 }
		}
	}
}
