// Persistence of Vision Ray Tracer Scene Description File
// File: whiteway.pov
// Vers: 2
// Desc: The White Way
// Date: 2011-06-18
// Auth: Felix Plesoianu <felixp7@yahoo.com>

#include "colors.inc"
#include "textures.inc"
//#include "math.inc"
#include "rand.inc"

#declare Ambiental = <0.5, 0.5, 0.5>;

#declare White_Ceramics =
texture {
	pigment { color White }
	finish {
		diffuse 0.6
		specular 0.8
		ambient Ambiental
	}
}

#declare Dark_Glass =
texture {
	pigment { color rgb <0.25, 0.25, 0> }
	finish {
		ambient <0.8, 0.8, 0.8>
		diffuse 0
		specular 0.2
		reflection {
			<0.35, 0.35, 0.11>
		}
	}
}

#declare Facade =
texture {
	checker texture { Dark_Glass }, texture { White_Ceramics }
	scale <1000, 2, 1000>
}


//background { SkyBlue }
//background { rgb <0.5, 0.65, 0.8> }
sky_sphere {
	pigment {
		gradient y
		color_map {
			[0.5 color White]
			[0.75 color rgb <0.5, 0.65, 0.8>]
		}
		scale 2
		translate -1
	}
}

// Aerial perspective
/*fog {
	fog_type 1 distance 3000
	color rgb <0.5, 0.65, 0.8>
}*/

light_source { <500, 1000, -500> color White parallel point_at <0, 0, 0> }

camera {
	location <17, 1.65, 50>
	look_at <0, 20, 800>
	angle 60

	focal_point <0, 20, 800>
	aperture 0.15
	blur_samples 20
}


// The ground
disc {
	<0, 0, 0>, <0, 1, 0>, 20000
	texture { White_Ceramics }
	normal { cells /*scale x * 10 + z * 10*/ }
}


#macro Mobile_Strip(X1, X2)
	polygon {
		5, <X1, 0.01, -100>, <X1, 0.01, 800>,
		<X2, 0.01, 800>, <X2, 0.01, -100>,
		<X1, 0.01, -100>
		texture { Brushed_Aluminum rotate y * 90 }
	}
#end

Mobile_Strip(2.5, 7.5)
Mobile_Strip(7.6, 9.6)
Mobile_Strip(9.7, 10.7)
Mobile_Strip(10.8, 11.8)
Mobile_Strip(11.9, 12.9)
Mobile_Strip(13, 15)

Mobile_Strip(-2.5, -7.5)
Mobile_Strip(-7.6, -9.6)
Mobile_Strip(-9.7, -10.7)
Mobile_Strip(-10.8, -11.8)
Mobile_Strip(-11.9, -12.9)
Mobile_Strip(-13, -15)

#declare Floor_Shape =
prism {
	linear_sweep
	linear_spline
	0, 2, 8,
	<0, 0>, <0, 45>, <5, 50>, <45, 50>,
	<50, 45>, <50, 5>, <45, 0>, <0, 0>
}

#declare Floor_Module =
union {
	object {
		Floor_Shape
		texture { Dark_Glass }
		scale <0.98, 1, 0.98>
	}
	object {
		Floor_Shape
		texture { White_Ceramics }
		translate y * 2
	}
}

#macro Building_Module(Num_Floors)
	union {
		#declare i = 0;
		#while (i < Num_Floors)
			#declare Hscale = 1 - i * 0.04;
			object {
				Floor_Module
				scale <Hscale, 1, Hscale>
				translate y * i * 4
			}
			#declare i = i + 1;
		#end
		translate <-25, 0, -25> // Center on origin.
	}
#end


#declare Building =
union {
	object {
		Building_Module(15)
		translate z * 25
		scale z * 2
	}
	object {
		Building_Module(10)
		translate x * 25 + z * 25
		rotate y * 180
		scale x * 2 + z * 2
	}
}

#declare j = 0;
#while (j < 10)
	object {
		Building
		translate <-100, 0, 200 + j * 200>
	}
	
	object {
		Building
		rotate y * 180
		translate <100, 0, 175 + j * 200>
	}
	#declare j = j + 1;
#end


#declare Palm_Branch_Segment =
union {
	cone {
		<0, 0, 0>, 0.05,
		<0, 0.6, 0>, 0.04
		texture { White_Wood }
	}
	union {
		#declare j = 0;
		#while (j <= 0.6)
			cone {
				<0, 0, 0>, 0.005,
				<-0.5, 0, 0>, 0.001
				scale <1, 7, 1>
				rotate z * -45
				translate y * j
				rotate y * RRand(10, 30, RdmA)
			}
			cone {
				<0, 0, 0>, 0.005,
				<0.5, 0, 0>, 0.001
				scale <1, 7, 1>
				rotate z * 45
				translate y * j
				rotate y * -RRand(10, 30, RdmA)
			}
			#declare j = j + 0.05;
		#end
		pigment { color Green }
	}
}

#declare Palm_Branch =
union {
	#declare j = 0;
	#while (j < 5)
		object {
			Palm_Branch_Segment
			scale <0.95, 1, 0.95>
			rotate x * j * 5
			translate y * j * 0.6
			translate z * j * j * 0.03 // Big time fudge.
		}
		#declare j = j + 1;
	#end
}

#declare Palm_Tree =
union {
	union {
		#declare j = 1;
		#while (j <= 20)
			object {
				Palm_Branch
				rotate <j * 5, j * 72>
			}
			#declare j = j + 1;
		#end
		translate y * 7
	}
	cone {
		<0, 0, 0>, 0.25,
		<0, 7, 0>, 0.10
		texture { White_Wood }
	}
}

#declare j = 0;
#while (j < 30)
	object {
		Palm_Tree
		rotate y * j * 15
		translate <0, 0, 75 + j * 25>
		pigment { transmit j / 30 }
	}
	/*object {
		Palm_Tree
		rotate y * j * 15
		translate <-17.5, 0, 75 + j * 25>
	}
	object {
		Palm_Tree
		rotate y * j * 15
		translate <17.5, 0, 75 + j * 25>
	}*/
	#declare j = j + 1;
#end

/*object {
	Palm_Branch
	rotate y * 45
	translate x * 17 + z * 55
}*/


#declare Pyramid_Floor =
union {
	box {
		<-115, 0, -115>, <115, 2, 115>
		texture { Dark_Glass }
		scale <0.98, 1, 0.98>
	}
	box {
		<-115, 0, -115>, <115, 2, 115>
		texture { White_Ceramics }
		translate y * 2
	}
}

#macro Pyramid(Num_Floors, Floor_Scale)
	union {
		#declare i = 0;
		#while (i < Num_Floors)
			#declare Hscale = 1 - i * Floor_Scale;
			object {
				Pyramid_Floor
				scale <Hscale, 1, Hscale>
				translate y * i * 4
			}
			#declare i = i + 1;
		#end
	}
#end

object {
	Pyramid(37, 0.0275)
	translate z * 2000
}


#declare Dark_Glass2 =
texture {
	pigment { color rgb <0.15, 0.15, 0.15> }
	finish {
		ambient <0.5, 0.5, 0.5>
		diffuse 0
		specular 0.2
		reflection {
			<0.25, 0.25, 0.25>
		}
	}
}

#declare Car_Body =
intersection {
	sphere {
		<0, 0, 0>, 0.5
		scale <2.1, 0.8, 3.4>
	}
	sphere {
		<0, 0, 0>, 1.5
	}
}

#declare Car_Top =
sphere {
	<0, 0, 0>, 0.5
	scale <1.3, 0.8, 2.1>
}

#declare Aileron =
sphere {
	<0, 0, 0>, 0.5
	scale <1.25, 0.2, 2.1>
}

#declare Wheel_Housing =
union {
	difference {
		sphere {
			<0, 0, 0>, 0.5
			scale <0.3, 0.8, 1.3>
		}
		sphere {
			<0, 0, 0>, 0.5
			scale <0.3, 0.8, 1.3>
			translate y * -0.5
		}
	}
	cylinder {
		<-0.1, 0, 0>, <0.1, 0, 0>, 0.25
		translate y * -0.2
		pigment { color Black }
	}
}

#declare Tail_Lights =
union {
	sphere {
		<0, 0, 0>, 0.1
		scale x * 2
		translate x * -0.3
	}
	sphere {
		<0, 0, 0>, 0.1
		scale x * 2
		translate x * 0.3
	}
}

#declare Car =
union {
	object {
		Car_Body
	}
	difference {
		union {
			object {
				Car_Top
				texture { Dark_Glass2 }
			}
			object {
				Aileron
				translate z * -0.1
			}
			rotate x * 10
			translate y * 0.3
		}
		difference {
			cylinder {
				<-1.3, 0, 0>, <1.3, 0, 0>, 0.3
			}
			cylinder {
				<-1.3, 0, 0>, <1.3, 0, 0>, 0.290
			}
			translate y * 0.3
		}
	}
	object {
		Wheel_Housing
		translate <0.8, 0, 0.8>
	}
	object {
		Wheel_Housing
		translate <-0.8, 0, 0.8>
	}
	object {
		Wheel_Housing
		translate <0.8, 0, -0.8>
	}
	object {
		Wheel_Housing
		translate <-0.8, 0, -0.8>
	}
	object {
		Tail_Lights
		translate z * -1.4
		texture { Dark_Glass2 pigment { color rgb <0.2, 0, 0> } }
	}

	texture {
		White_Ceramics
		pigment { color rgb <1, 0.5, 0.8> }
		finish { ambient 0.25 metallic }
	}
}

/*object {
	Car
	rotate y * -45
	translate <17, 0.5, 55>
}*/

object {
	Car
	translate <20, 0.5, 55>
}

object {
	Car
	translate <23, 0.5, 65>
}

object {
	Car
	translate <20, 0.5, 85>
}

object {
	Car
	translate <30, 0.5, 115>
}

object {
	Car
	translate <17, 0.5, 165>
}


object {
	Car
	rotate y * 180
	translate <-17, 0.5, 125>
}

object {
	Car
	rotate y * 180
	translate <-20, 0.5, 175>
}
